{% extends "webclient/base/base_container.html" %} {% load i18n %} {% comment %} {% endcomment %} {% block link %} {{ block.super }} {% endblock %} {% block script %} {{ block.super }}
{% endblock %} {% block left %}
{% endblock %} {% block center %}
Filter Results
{% comment %}

# {{ eContext.breadcrumb.2 }} {{ eContext.breadcrumb.1 }} {% if controller.day_items_size %}{{ controller.total_items_size }} {% plural controller.total_items_size 'item' 'items' %}{% endif %}

{% endcomment %}
{% endblock %}